@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 import json
+from enum import Enum
 from typing import Union, List
 
 import sqlalchemy as sql
@@ -12,6 +13,13 @@ from mipdb.database import METADATA_TABLE
 from mipdb.dataelements import CommonDataElement
 from mipdb.exceptions import UserInputError
 from mipdb.schema import Schema
+RECORDS_PER_COPY = 100000
+
+
+class User(Enum):
+    executor = "executor"
+    admin = "admin"
+    guest = "guest"
 
 
 @compiles(sql.types.JSON, "monetdb")
@@ -45,6 +53,7 @@ class Table(ABC):
 
     def create(self, db: Union[DataBase, Connection]):
         db.create_table(self._table)
+        db.grant_select_access_rights(self._table, User.executor.value)
 
     def exists(self, db: Union[DataBase, Connection]):
         return db.table_exists(self._table)
@@ -87,9 +96,6 @@ class DataModelTable(Table):
         if db.get_executor():
             self.data_model_id_seq.drop(db.get_executor())
 
-    def create(self, db: Union[DataBase, Connection]):
-        db.create_table(self.table)
-
     def get_data_models(self, db, columns: list = None):
         if columns and not set(columns).issubset(self.table.columns.keys()):
             non_existing_columns = list(set(columns) - set(self.table.columns.keys()))
@@ -164,9 +170,6 @@ class DatasetsTable(Table):
         if db.get_executor():
             self.dataset_id_seq.drop(db.get_executor())
 
-    def create(self, db: Union[DataBase, Connection]):
-        db.create_table(self.table)
-
     def get_values(self, db, data_model_id=None, columns=None):
         if columns and not set(columns).issubset(self.table.columns.keys()):
             non_existing_columns = list(set(columns) - set(self.table.columns.keys()))
@@ -235,9 +238,6 @@ class ActionsTable(Table):
         if db.get_executor():
             self.action_id_seq.drop(db.get_executor())
 
-    def create(self, db: Union[DataBase, Connection]):
-        db.create_table(self.table)
-
     def insert_values(self, values, db: Union[DataBase, Connection]):
         # Needs to be overridden because sqlalchemy and monetdb are not cooperating
         # well when inserting values to JSON columns
@@ -390,10 +390,30 @@ class TemporaryTable(Table):
             prefixes=["TEMPORARY"],
         )
 
-    def validate_data(self, cdes_with_min_max, cdes_with_enumerations, db):
+    def validate_csv(self, csv_path, cdes_with_min_max, cdes_with_enumerations, db):
+        validated_datasets = []
+        offset = 2
+
+        while True:
+            self.load_csv(csv_path=csv_path, records=RECORDS_PER_COPY, db=db)
+            validated_datasets = set(validated_datasets) | set(
+                self.get_unique_datasets(db)
+            )
+
+            self._validate_enumerations_restriction(cdes_with_enumerations, db)
+            self._validate_min_max_restriction(cdes_with_min_max, db)
+
+            # If the temp contains fewer rows than RECORDS_PER_COPY
+            # that means we have read all the records in the csv and we need to stop the iteration.
+            table_count = self.get_row_count(db=db)
+            self.delete(db)
+
+            if table_count < RECORDS_PER_COPY:
+                break
+
+            offset += RECORDS_PER_COPY
+        return validated_datasets
 
-        self._validate_enumerations_restriction(cdes_with_enumerations, db)
-        self._validate_min_max_restriction(cdes_with_min_max, db)
 
     def _validate_min_max_restriction(self, cdes_with_min_max, db):
         for cde, min_max in cdes_with_min_max.items():
